You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by hi...@apache.org on 2016/09/09 21:43:33 UTC

[36/83] [abbrv] [partial] incubator-geode git commit: GEODE-37 changed import statement from com.gemstone.gemfire to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/package.html
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/package.html b/geode-core/src/main/java/org/apache/geode/cache/package.html
index 84a071b..5e0cd92 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/package.html
+++ b/geode-core/src/main/java/org/apache/geode/cache/package.html
@@ -46,16 +46,16 @@ the programmer's guide for performance guidelines.</p>
 Top</a>
 
 <p>Function execution facilitates movement of behavior in the form of
-{@linkplain com.gemstone.gemfire.cache.execute.Function}s executed using the
-{@linkplain com.gemstone.gemfire.cache.execute.FunctionService
+{@linkplain org.apache.geode.cache.execute.Function}s executed using the
+{@linkplain org.apache.geode.cache.execute.FunctionService
 Function Execution Service}.  A Function may generate results from
-parallel execution on many {@linkplain com.gemstone.gemfire.cache.execute.FunctionService#onMembers(String...) members}
-, or several {@linkplain com.gemstone.gemfire.cache.execute.FunctionService#onServers(Pool)
+parallel execution on many {@linkplain org.apache.geode.cache.execute.FunctionService#onMembers(String...) members}
+, or several {@linkplain org.apache.geode.cache.execute.FunctionService#onServers(Pool)
 Cache Servers}, or perhaps evaluating {@link
-com.gemstone.gemfire.cache.execute.FunctionService#onRegion(Region) Region} data.  A {@linkplain
-com.gemstone.gemfire.cache.execute.ResultCollector} collects and
+org.apache.geode.cache.execute.FunctionService#onRegion(Region) Region} data.  A {@linkplain
+org.apache.geode.cache.execute.ResultCollector} collects and
 possibly processes those results for consumption.  For more information look to the
-<a href="{@docRoot}/com/gemstone/gemfire/cache/execute/package-summary.html#package_description">com.gemstone.gemfire.cache.execute</a> package.
+<a href="{@docRoot}/org/apache/geode/cache/execute/package-summary.html#package_description">org.apache.geode.cache.execute</a> package.
 </p>
 
 <a name="distcache"><h2>Distributed Caching</h2><a href="#top">Back to Top</a>
@@ -68,41 +68,41 @@ efficiently shared among multiple threads in a VM, multiple VMs
 running on the same physical machine, and multiple VMs running on
 multiple machines.  Cached data resides in "regions" whose
 contents are stored in a VM's heap.</p>
-<p>The {@link com.gemstone.gemfire.cache.CacheFactory} class provides
+<p>The {@link org.apache.geode.cache.CacheFactory} class provides
 the entry point to the caching API.  A <code>CacheFactory</code> is
-configured to create a {@linkplain com.gemstone.gemfire.cache.Cache
+configured to create a {@linkplain org.apache.geode.cache.Cache
 "cache instance"} that resides in the VM.  The cache factory also allows
-the {@link com.gemstone.gemfire.distributed.DistributedSystem} to be configured.</p>
+the {@link org.apache.geode.distributed.DistributedSystem} to be configured.</p>
 
 <a name="regions"><h2>Cache Regions</h2></a><a href="#top">Back to Top</a>
 
 <p>Application data is cached in a {@linkplain
-com.gemstone.gemfire.cache.Region "region"}.  The {@link
-com.gemstone.gemfire.cache.RegionFactory} class provides the simpliest
-entry point into the {@linkplain com.gemstone.gemfire.cache.Region}
-API. A {@link com.gemstone.gemfire.cache.Region} implements {@link java.util.Map},
+org.apache.geode.cache.Region "region"}.  The {@link
+org.apache.geode.cache.RegionFactory} class provides the simpliest
+entry point into the {@linkplain org.apache.geode.cache.Region}
+API. A {@link org.apache.geode.cache.Region} implements {@link java.util.Map},
 however, it also provides caching behavior such as data loading,
 eviction control, and distribution.  Every region has a name and
 regions may be nested to provide a cache-naming hierarchy ("parent
 regions" with "subregions").  The root regions of the naming hierarchy
 (that is, the regions with no parent) are obtained with the {@link
-com.gemstone.gemfire.cache.Cache#rootRegions} method.
+org.apache.geode.cache.Cache#rootRegions} method.
 Any region may be obtained with the {@link
-com.gemstone.gemfire.cache.Cache#getRegion} method.</p>
+org.apache.geode.cache.Cache#getRegion} method.</p>
 
 <p>Region properties such as the region's cache loader, data policy, and
 storage model are specified by an instance of {@link
-com.gemstone.gemfire.cache.RegionAttributes}.  A region
+org.apache.geode.cache.RegionAttributes}.  A region
 <code>RegionAttributes</code> object can be specified when {@linkplain
-com.gemstone.gemfire.cache.Region#createSubregion creating} a
+org.apache.geode.cache.Region#createSubregion creating} a
 region.</p>
 
 <a name="partition"><h2>Partitioned Regions</h2><a href="#top">Back to Top</a>
 
 <p>Region data can be partitioned across many distributed system members to create one large logical heap.
-The data policy must be set to {@link com.gemstone.gemfire.cache.DataPolicy#PARTITION}
-or {@link com.gemstone.gemfire.cache.DataPolicy#PERSISTENT_PARTITION}.
-{@link com.gemstone.gemfire.cache.PartitionAttributes} are used to configure
+The data policy must be set to {@link org.apache.geode.cache.DataPolicy#PARTITION}
+or {@link org.apache.geode.cache.DataPolicy#PERSISTENT_PARTITION}.
+{@link org.apache.geode.cache.PartitionAttributes} are used to configure
 a partitioned region.  A partitioned region can be configured to be
 highly available, surviving the loss of one or more system members, by
 maintaining copies of data.  These extra copies also benefit read operations by
@@ -115,13 +115,13 @@ the entire Region in the face of a full garbage collection cycle.</p>
 </p>
 
 <p>Partitioned Regions support custom partitioning with the use of a
-{@link com.gemstone.gemfire.cache.PartitionResolver} and can be
+{@link org.apache.geode.cache.PartitionResolver} and can be
 associated together or
-{@linkplain com.gemstone.gemfire.cache.PartitionAttributesFactory#setColocatedWith(String)
+{@linkplain org.apache.geode.cache.PartitionAttributesFactory#setColocatedWith(String)
 colocated} to allow for efficient data usage.
 </p>
 
-<p>A {@link com.gemstone.gemfire.cache.partition.PartitionRegionHelper}
+<p>A {@link org.apache.geode.cache.partition.PartitionRegionHelper}
 class provides methods to facilitate usage of Partitioned
 Regions with other features, for example when used in conjunction with <a
 href="#functions">function execution</a>.
@@ -132,13 +132,13 @@ href="#functions">function execution</a>.
 <!-- Life cycle, constrained keys -->
 
 <p>A region contains key/value pairs of objects known as the region's
-{@linkplain com.gemstone.gemfire.cache.Region.Entry "entries"}.  The
+{@linkplain org.apache.geode.cache.Region.Entry "entries"}.  The
 <code>Region</code> class provides a number of methods for
 manipulating the region's entries such as {@link
-com.gemstone.gemfire.cache.Region#create create}, {@link
-com.gemstone.gemfire.cache.Region#put put}, {@link
-com.gemstone.gemfire.cache.Region#invalidate invalidate}, and {@link
-com.gemstone.gemfire.cache.Region#destroy destroy} .  The following
+org.apache.geode.cache.Region#create create}, {@link
+org.apache.geode.cache.Region#put put}, {@link
+org.apache.geode.cache.Region#invalidate invalidate}, and {@link
+org.apache.geode.cache.Region#destroy destroy} .  The following
 diagram describes the life cycle of a region entry.</p>
 
 <CENTER>
@@ -149,9 +149,9 @@ diagram describes the life cycle of a region entry.</p>
 <a name="consistency"><h2>Distribution and Consistency Models</h2><a href="#top">Back to Top</a>
 
 <p>A region's {@linkplain
-com.gemstone.gemfire.cache.RegionAttributes#getScope scope} attribute
+org.apache.geode.cache.RegionAttributes#getScope scope} attribute
 determines how the region's entries will be distributed to other
-caches.  A region with {@linkplain com.gemstone.gemfire.cache.Scope#LOCAL local} scope
+caches.  A region with {@linkplain org.apache.geode.cache.Scope#LOCAL local} scope
 will not distribute any of its changes to any other members of the
 distributed system, nor will it receive changes when another cache
 instance is updated.</p>
@@ -162,25 +162,25 @@ that change is distributed to the other members of the distributed
 system that have created that region in their cache instance.  There
 are three kinds of distributed scope, each of which guarantees a
 different level of consistency for distributed data.  {@linkplain
-com.gemstone.gemfire.cache.Scope#GLOBAL "Global"
+org.apache.geode.cache.Scope#GLOBAL "Global"
 scope} provides the highest level of data consistency by obtaining a
-{@linkplain com.gemstone.gemfire.distributed.DistributedLockService
+{@linkplain org.apache.geode.distributed.DistributedLockService
 distributed lock} on a region entry before propagating a change to other
 members of the distributed system.  With globally-scoped regions, only
 one thread in the entire distributed system may modify the region entry at a
 time.</p>
 
-<p>{@linkplain com.gemstone.gemfire.cache.Scope#DISTRIBUTED_ACK
+<p>{@linkplain org.apache.geode.cache.Scope#DISTRIBUTED_ACK
 "Distributed ACK" scope} provides slightly weaker data consistency
 than global scope.  With distributed ACK scope, the method that
 modifies the region (such as a call to {@link
-com.gemstone.gemfire.cache.Region#destroy}) will not return until an
+org.apache.geode.cache.Region#destroy}) will not return until an
 acknowledgment of the change has been received from every member of
 the distributed system.  Multiple threads may modify the region
 concurrently, but the modifying thread may proceed knowing that its
 change to the region has been seen by all other members.</p>
 
-<p>{@linkplain com.gemstone.gemfire.cache.Scope#DISTRIBUTED_NO_ACK
+<p>{@linkplain org.apache.geode.cache.Scope#DISTRIBUTED_NO_ACK
 "Distributed NO ACK" scope} provides the weakest data consistency of
 all the scopes, but also provides the best performance.  A method invocation that
 modifies a region with distributed NO ACK scope will return
@@ -196,32 +196,32 @@ may be stored in either the JVM's heap or on a disk drive.
 
 <a name="dataPolicy"><h3>Data Policy</h3></a><a href="#top">Back to Top</a>
 
-<p>A region's {@linkplain com.gemstone.gemfire.cache.DataPolicy
+<p>A region's {@linkplain org.apache.geode.cache.DataPolicy
 "data policy" attribute} determines if data is stored in the local cache.
-The {@linkplain com.gemstone.gemfire.cache.DataPolicy#NORMAL normal policy}
+The {@linkplain org.apache.geode.cache.DataPolicy#NORMAL normal policy}
 will store region data in the local cache.
-The {@linkplain com.gemstone.gemfire.cache.DataPolicy#EMPTY empty policy}
+The {@linkplain org.apache.geode.cache.DataPolicy#EMPTY empty policy}
 will never store region data in the local cache. They act as proxy regions that
 distribute write operations to others and receive events from others.
-The {@linkplain com.gemstone.gemfire.cache.DataPolicy#withReplication replication policies}
+The {@linkplain org.apache.geode.cache.DataPolicy#withReplication replication policies}
 may reduce the number of net searches that a caching application has to be perform,
 and can provide a backup mechanism. The replicated region initializes itself when
 it is created with the keys and value of the region as found in other caches.
-The {@linkplain com.gemstone.gemfire.cache.DataPolicy#REPLICATE replicate policy} simply stores the relicate data in memory and
-the {@linkplain com.gemstone.gemfire.cache.DataPolicy#PERSISTENT_REPLICATE persistent replicate policy} stores the data in memory and disk.
-The {@linkplain com.gemstone.gemfire.cache.DataPolicy#withPartitioning partition policies} are used for <a href="#partition">partitioned</a> regions.
-The {@linkplain com.gemstone.gemfire.cache.DataPolicy#PARTITION partition policy} simply stores the <a href="#partition">partitioned</a> data in memory and
-the {@linkplain com.gemstone.gemfire.cache.DataPolicy#PERSISTENT_PARTITION persistent partition policy} stores the <a href="#partition">partitioned</a> data in memory and disk.
+The {@linkplain org.apache.geode.cache.DataPolicy#REPLICATE replicate policy} simply stores the relicate data in memory and
+the {@linkplain org.apache.geode.cache.DataPolicy#PERSISTENT_REPLICATE persistent replicate policy} stores the data in memory and disk.
+The {@linkplain org.apache.geode.cache.DataPolicy#withPartitioning partition policies} are used for <a href="#partition">partitioned</a> regions.
+The {@linkplain org.apache.geode.cache.DataPolicy#PARTITION partition policy} simply stores the <a href="#partition">partitioned</a> data in memory and
+the {@linkplain org.apache.geode.cache.DataPolicy#PERSISTENT_PARTITION persistent partition policy} stores the <a href="#partition">partitioned</a> data in memory and disk.
 </p>
 
 <a name="storageOnDisk"><h3>Disk Storage</h3></a>
 
 <p>GemFire supports several modes of region persistence as determined by
-the {@linkplain com.gemstone.gemfire.cache.DataPolicy#withPersistence
+the {@linkplain org.apache.geode.cache.DataPolicy#withPersistence
 persistent data policies} and the {@link
-com.gemstone.gemfire.cache.RegionAttributes#getEvictionAttributes}'s {@linkplain
-com.gemstone.gemfire.cache.EvictionAction eviction action}
-of {@linkplain com.gemstone.gemfire.cache.EvictionAction#OVERFLOW_TO_DISK overflow-to-disk}.
+org.apache.geode.cache.RegionAttributes#getEvictionAttributes}'s {@linkplain
+org.apache.geode.cache.EvictionAction eviction action}
+of {@linkplain org.apache.geode.cache.EvictionAction#OVERFLOW_TO_DISK overflow-to-disk}.
 The following table summarizes the different modes and their configuration.</p>
 
 <table border="1">
@@ -254,7 +254,7 @@ The following table summarizes the different modes and their configuration.</p>
  <td>false</td>
  <td>Disk for persistence</td>
  <td>All data in the region is {@linkplain
-     com.gemstone.gemfire.cache.DiskStore scheduled to be
+     org.apache.geode.cache.DiskStore scheduled to be
      written} to disk as soon as it is placed in the region.  Thus,
      the data on disk contains a complete backup of the region.  No
      information about recently used data is maintained and,
@@ -269,7 +269,7 @@ The following table summarizes the different modes and their configuration.</p>
  <td>true</td>
  <td>Disk for overflow and persistence</td>
  <td>All data in the region is {@linkplain
-     com.gemstone.gemfire.cache.DiskStore scheduled to be
+     org.apache.geode.cache.DiskStore scheduled to be
      written} to disk as soon as it is placed in the region.  But
      unlike "disk for persistence" mode, the least recently used data will
      be removed from the VM once the eviction controller's
@@ -284,15 +284,15 @@ that store data on disk.</p>
 <UL>
 
 <LI>Operations (such as {@link
-com.gemstone.gemfire.cache.Region#invalidate invalidate} and {@link
-com.gemstone.gemfire.cache.Region#destroy}) that remove data from the
+org.apache.geode.cache.Region#invalidate invalidate} and {@link
+org.apache.geode.cache.Region#destroy}) that remove data from the
 cache also remove data from disk.  In order for data to be removed
 from the VM and not from disk, {@linkplain
-com.gemstone.gemfire.cache.EvictionAction#OVERFLOW_TO_DISK}
+org.apache.geode.cache.EvictionAction#OVERFLOW_TO_DISK}
 overflow} must be used.</LI>
 
 <LI>When disk overflow is enabled, only the {@linkplain
-com.gemstone.gemfire.cache.Region.Entry#getValue value} of the least
+org.apache.geode.cache.Region.Entry#getValue value} of the least
 recently used entry is removed from the VM.  That is, the entry's key
 and the entry itself remain in the VM.</LI>
 
@@ -306,40 +306,40 @@ the same region is created.</LI>
 <LI>GemFire will look for the value of a region entry on disk before
 it will look in other cache instances.  That is, it will not perform a
 net search or a {@linkplain
-com.gemstone.gemfire.cache.CacheLoader#load load} if the value exists
+org.apache.geode.cache.CacheLoader#load load} if the value exists
 on disk.</LI>
 
 <LI>When data is read from or written to disk, no {@linkplain
-com.gemstone.gemfire.cache.CacheEvent cache events} are fired.</LI>
+org.apache.geode.cache.CacheEvent cache events} are fired.</LI>
 
 <LI>Region operations such as {@linkplain
-com.gemstone.gemfire.cache.Region#destroy destroy} and {@linkplain
-com.gemstone.gemfire.cache.Region#invalidate invalidate} effect the
+org.apache.geode.cache.Region#destroy destroy} and {@linkplain
+org.apache.geode.cache.Region#invalidate invalidate} effect the
 data that is stored on disk in addition to the data stored in the VM.
 That is, if an entry is destroyed in the VM (even by an {@link
-com.gemstone.gemfire.cache.ExpirationAction}), it will also be destroyed on disk.</LI>
+org.apache.geode.cache.ExpirationAction}), it will also be destroyed on disk.</LI>
 
 </UL>
 
 <h3>Region backup and restore</h3>
 
 Any GemFire resource that stores data on disk does so by configuring itself
-to use a {@link com.gemstone.gemfire.cache.DiskStore disk store}.
+to use a {@link org.apache.geode.cache.DiskStore disk store}.
 Disk stores are created using the
-{@link com.gemstone.gemfire.cache.DiskStoreFactory disk store factory API} or by
+{@link org.apache.geode.cache.DiskStoreFactory disk store factory API} or by
 configuring them in XML using the "disk-store" element.
 
 Region's specify the disk store they are in by setting the
-{@link com.gemstone.gemfire.cache.RegionAttributes#getDiskStoreName disk store name region attribute}.
+{@link org.apache.geode.cache.RegionAttributes#getDiskStoreName disk store name region attribute}.
 
-<P>A {@linkplain com.gemstone.gemfire.cache.Region#put put} on a region
+<P>A {@linkplain org.apache.geode.cache.Region#put put} on a region
 that is configured to have a disk "backup" (by using a
-{@linkplain com.gemstone.gemfire.cache.DataPolicy#withPersistence
+{@linkplain org.apache.geode.cache.DataPolicy#withPersistence
 persistent data policy})
  will result in the immediate scheduling of a
 disk write according to the region's {@link
-com.gemstone.gemfire.cache.DiskStore disk store}
-and the  {@linkplain com.gemstone.gemfire.cache.RegionAttributes#isDiskSynchronous
+org.apache.geode.cache.DiskStore disk store}
+and the  {@linkplain org.apache.geode.cache.RegionAttributes#isDiskSynchronous
 disk synchronous region attribute}.</P>
 
 <P>The actual backup data is stored in each of the disk store's specified disk
@@ -381,15 +381,15 @@ data.</P>
 
 <!-- CacheLoader, netSearch, netLoad -->
 
-<p>A {@linkplain com.gemstone.gemfire.cache.CacheLoader cache loader}
+<p>A {@linkplain org.apache.geode.cache.CacheLoader cache loader}
 allows data from outside of the VM to be placed into a region.  When
-{@link com.gemstone.gemfire.cache.Region#get} is called for a region
+{@link org.apache.geode.cache.Region#get} is called for a region
 entry that has a <code>null</code> value, the {@link
-com.gemstone.gemfire.cache.CacheLoader#load load} method of the
+org.apache.geode.cache.CacheLoader#load load} method of the
 region's cache loader is invoked.  The <code>load</code> method
 creates the value for the desired key by performing an operation such
 as a database query.  The <code>load</code> may also perform a
-{@linkplain com.gemstone.gemfire.cache.LoaderHelper#netSearch net
+{@linkplain org.apache.geode.cache.LoaderHelper#netSearch net
 search} that will look for the value in a cache instance hosted by
 another member of the distributed system.</p>
 
@@ -404,7 +404,7 @@ the remote cache's region.</p>
 
 <a name="cachewriter"><h2>Cache Writers</h2><a href="#top">Back to Top</a>
 
-<p>The {@link com.gemstone.gemfire.cache.CacheWriter} is a type of event handler
+<p>The {@link org.apache.geode.cache.CacheWriter} is a type of event handler
 that is invoked <em>synchronously before</em> the cache is modified, and has
 the ability to abort the operation. Only one CacheWriter in the distributed system
 is invoked before the operation that would modify a cache. A CacheWriter
@@ -413,13 +413,13 @@ is typically used to update an external database.</p>
 <a name="expiration"><h2>Expiration</h2></a><a href="#top">Back to Top</a>
 
 <p>Sometimes cached data has a limited lifetime.  The region attributes
-{@linkplain com.gemstone.gemfire.cache.RegionAttributes#getRegionTimeToLive
+{@linkplain org.apache.geode.cache.RegionAttributes#getRegionTimeToLive
 regionTimeToLive}, {@linkplain
-com.gemstone.gemfire.cache.RegionAttributes#getRegionIdleTimeout
+org.apache.geode.cache.RegionAttributes#getRegionIdleTimeout
 regionIdleTimeout}, {@linkplain
-com.gemstone.gemfire.cache.RegionAttributes#getEntryTimeToLive
+org.apache.geode.cache.RegionAttributes#getEntryTimeToLive
 entryTimeToLive}, and {@linkplain
-com.gemstone.gemfire.cache.RegionAttributes#getEntryIdleTimeout
+org.apache.geode.cache.RegionAttributes#getEntryIdleTimeout
 entryIdleTimeout}, specify how data is handled when it becomes too
 old.  There are two conditions under which cache data is considered
 too old: data has resided unchanged in a region for a given amount of time
@@ -430,25 +430,25 @@ time").  GemFire's caching implementation launches an "expiration
 thread" that periodically monitors region entries and will expire
 those that have become too old.  When a region entry expires, it can
 either be {@linkplain
-com.gemstone.gemfire.cache.ExpirationAction#INVALIDATE
+org.apache.geode.cache.ExpirationAction#INVALIDATE
 invalidated},  {@linkplain
-com.gemstone.gemfire.cache.ExpirationAction#DESTROY
+org.apache.geode.cache.ExpirationAction#DESTROY
 destroyed}, {@linkplain
-com.gemstone.gemfire.cache.ExpirationAction#LOCAL_INVALIDATE locally
+org.apache.geode.cache.ExpirationAction#LOCAL_INVALIDATE locally
 invalidated}, or {@linkplain
-com.gemstone.gemfire.cache.ExpirationAction#LOCAL_DESTROY locally destroyed}.</p>
+org.apache.geode.cache.ExpirationAction#LOCAL_DESTROY locally destroyed}.</p>
 
 <a name="event"><h2>Cache Events</h2></a><a href="#top">Back to Top</a>
 
-<p>The {@link com.gemstone.gemfire.cache.CacheListener}
+<p>The {@link org.apache.geode.cache.CacheListener}
 interface provides callback methods that are invoked synchronously in
 response to certain operations (such as a <code>put</code> or
 <code>invalidate</code>) being performed on a region.  The event
 listener for a region is specified with the {@link
-com.gemstone.gemfire.cache.AttributesFactory#setCacheListener
+org.apache.geode.cache.AttributesFactory#setCacheListener
 setCacheListener} method.  Each callback method on the
 <code>CacheListener</code> receives a {@link
-com.gemstone.gemfire.cache.CacheEvent} describing the operation
+org.apache.geode.cache.CacheEvent} describing the operation
 that caused the callback to be invoked and possibly containing information
 relevant to the operation
 (such as the old and new values of a region entry).</p>
@@ -462,7 +462,7 @@ instance, an eviction controller could keep track of the sizes of the
 entry values.  Before a new entry is added, the eviction controller
 could remove the entry with the largest value to free up space in
 the cache instance for new data.  GemFire provides {@link
-com.gemstone.gemfire.cache.EvictionAttributes} that will create an eviction controller
+org.apache.geode.cache.EvictionAttributes} that will create an eviction controller
 that destroys the "least recently used" Region Entry once the Region
 exceeds a given number of entries.</p>
 
@@ -470,7 +470,7 @@ exceeds a given number of entries.</p>
 
 <!-- API statistics and VSD statistics -->
 
-<p>The {@link com.gemstone.gemfire.cache.CacheStatistics} class
+<p>The {@link org.apache.geode.cache.CacheStatistics} class
 provides statistics information about the usage of a region or entry.
 Statistics are often used by eviction controllers to determine which
 entries should be invalidated or destroyed when the region reaches its
@@ -497,13 +497,13 @@ href="{@docRoot}/javadoc-images/example3-cache.xml">example3</A>.
 In this configuration, GemFire cache regions are configured as
 clients to regions in GemFire server caches running in a separate
 distributed system.
-The GemFire <a href="{@docRoot}/com/gemstone/gemfire/cache/server/package-summary.html#package_description">servers</a>
+The GemFire <a href="{@docRoot}/org/apache/geode/cache/server/package-summary.html#package_description">servers</a>
 are generally run as cacheserver processes.
-<a href="{@docRoot}/com/gemstone/gemfire/cache/client/package-summary.html#package_description">Clients</a>
+<a href="{@docRoot}/org/apache/geode/cache/client/package-summary.html#package_description">Clients</a>
 are configured with a
-{@linkplain com.gemstone.gemfire.cache.client.ClientCache client cache}
+{@linkplain org.apache.geode.cache.client.ClientCache client cache}
 which has a default
-{@linkplain com.gemstone.gemfire.cache.client.Pool pool}
+{@linkplain org.apache.geode.cache.client.Pool pool}
 that manages connections to the server caches
 which are used by the client regions.
 When a client updates its region, the update is forwarded to the server.
@@ -511,9 +511,9 @@ When a client get results in a local cache miss,
 the get request is forwarded to the server.
 The clients may also subscribe to server-side events.
 For more information on the client see the
-<a href="{@docRoot}/com/gemstone/gemfire/cache/client/package-summary.html#package_description">client</a>.
+<a href="{@docRoot}/org/apache/geode/cache/client/package-summary.html#package_description">client</a>.
 For more information on the server see the
-<a href="{@docRoot}/com/gemstone/gemfire/cache/server/package-summary.html#package_description">server</a>.</p>
+<a href="{@docRoot}/org/apache/geode/cache/server/package-summary.html#package_description">server</a>.</p>
 
 <a name="tx"><h2>Cache Transactions</h2><a href="#top">Back to Top</a>
 
@@ -561,45 +561,45 @@ one action reflecting the sum of all three.
 
 <p>The GemFire region can be configured to require the
 presence of one or more user-defined membership roles.  Each {@link
-com.gemstone.gemfire.distributed.Role} is assigned to any number of
+org.apache.geode.distributed.Role} is assigned to any number of
 applications when each application connects to the GemFire distributed
-system.  {@link com.gemstone.gemfire.cache.MembershipAttributes} are
+system.  {@link org.apache.geode.cache.MembershipAttributes} are
 then used to specify which {@linkplain
-com.gemstone.gemfire.cache.MembershipAttributes#getRequiredRoles roles
+org.apache.geode.cache.MembershipAttributes#getRequiredRoles roles
 are required} to be online and present in that region's membership
 for access to the cache region being configured.</p>
 
 <p>In addition to specifying which roles are required,
 <code>MembershipAttributes</code> are used to specify the {@link
-com.gemstone.gemfire.cache.LossAction}. The loss action determines how
+org.apache.geode.cache.LossAction}. The loss action determines how
 access to the region is affected when one or more required roles are
 offline and no longer present in the system membership. The region can be
 made completely {@linkplain
-com.gemstone.gemfire.cache.LossAction#NO_ACCESS "NO_ACCESS"},
+org.apache.geode.cache.LossAction#NO_ACCESS "NO_ACCESS"},
 which means that the application cannot read from or write to that region.
-{@linkplain com.gemstone.gemfire.cache.LossAction#LIMITED_ACCESS
+{@linkplain org.apache.geode.cache.LossAction#LIMITED_ACCESS
 "LIMITED_ACCESS"} means that the application cannot write to that region.
-{@linkplain com.gemstone.gemfire.cache.LossAction#FULL_ACCESS
+{@linkplain org.apache.geode.cache.LossAction#FULL_ACCESS
 "FULL_ACCESS"} means that the application can read from and write to that
 region as normal. If "FULL_ACCESS" is selected,
 then the application would only be aware of the missing required role if it
-registered a {@link com.gemstone.gemfire.cache.RegionRoleListener}.
+registered a {@link org.apache.geode.cache.RegionRoleListener}.
 This listener provides callbacks to notify the application when required
 roles are gained or lost, thus providing for custom integration of required
 roles with the application.</p>
 
-<p>{@link com.gemstone.gemfire.cache.ResumptionAction} defined in the
+<p>{@link org.apache.geode.cache.ResumptionAction} defined in the
 <code>MembershipAttributes</code> specifies how the application responds
 to having a missing required role return to the distributed membership.
-{@linkplain com.gemstone.gemfire.cache.ResumptionAction#NONE "None"}
+{@linkplain org.apache.geode.cache.ResumptionAction#NONE "None"}
 results in no special action, while {@linkplain
-com.gemstone.gemfire.cache.ResumptionAction#REINITIALIZE "Reinitialize"}
+org.apache.geode.cache.ResumptionAction#REINITIALIZE "Reinitialize"}
 causes the region to be reinitialized.  Reinitializing the region will
 clear all entries from that region.  If it is a replicate, the
 region will repopulate with entries available from other distributed
 members.</p>
 
-<p>{@link com.gemstone.gemfire.cache.RequiredRoles} provides methods to
+<p>{@link org.apache.geode.cache.RequiredRoles} provides methods to
 check for missing required roles for a region and to wait until all required
 roles are present. In addition, this class can be used to check if a role
 is currently present in a region's membership.</p>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListener.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListener.java
index 44696f6..9a9124c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListener.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
-import com.gemstone.gemfire.cache.PartitionAttributesFactory;
-import com.gemstone.gemfire.cache.Region;
+import org.apache.geode.cache.PartitionAttributesFactory;
+import org.apache.geode.cache.Region;
 
 /**
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListenerAdapter.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListenerAdapter.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListenerAdapter.java
index f10f8ef..147de78 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListenerAdapter.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionListenerAdapter.java
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
-import com.gemstone.gemfire.cache.Region;
+import org.apache.geode.cache.Region;
 
 /**
  * <p>Utility class that implements all methods in <code>PartitionListener</code>
  * with empty implementations. Applications can subclass this class and only
  * override the methods of interest.<p>
  * 
- * <p>Subclasses declared in a Cache XML file, it must also implement {@link com.gemstone.gemfire.cache.Declarable}
+ * <p>Subclasses declared in a Cache XML file, it must also implement {@link org.apache.geode.cache.Declarable}
  * </p>
  * 
  * Note : Please request help on the Geode developer mailing list

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionMemberInfo.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionMemberInfo.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionMemberInfo.java
index 1057d20..10e0536 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionMemberInfo.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionMemberInfo.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
-import com.gemstone.gemfire.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedMember;
 
 /**
  * Describes a member that has been configured to provide storage space for
@@ -38,7 +38,7 @@ public interface PartitionMemberInfo {
   
   /**
    * Returns the {@link 
-   * com.gemstone.gemfire.cache.PartitionAttributes#getLocalMaxMemory() max 
+   * org.apache.geode.cache.PartitionAttributes#getLocalMaxMemory() max 
    * memory} in bytes that the member was configured to provide for storage
    * of data for the partitioned region.
    * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionNotAvailableException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionNotAvailableException.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionNotAvailableException.java
index 395e9b4..a7c4a7b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionNotAvailableException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionNotAvailableException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * This exception is thrown when for the given fixed partition, datastore

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRebalanceInfo.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionHelper.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionHelper.java
index f3852a9..38f2622 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionHelper.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionHelper.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
 import java.util.Collections;
 import java.util.HashSet;
@@ -23,31 +23,31 @@ import java.util.Map;
 import java.util.Set;
 import java.util.TreeSet;
 
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.DataPolicy;
-import com.gemstone.gemfire.cache.PartitionAttributes;
-import com.gemstone.gemfire.cache.PartitionAttributesFactory;
-import com.gemstone.gemfire.cache.PartitionResolver;
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.control.RebalanceResults;
-import com.gemstone.gemfire.cache.control.ResourceManager;
-import com.gemstone.gemfire.cache.execute.Function;
-import com.gemstone.gemfire.cache.execute.FunctionService;
-import com.gemstone.gemfire.cache.execute.RegionFunctionContext;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.internal.cache.ColocationHelper;
-import com.gemstone.gemfire.internal.cache.FixedPartitionAttributesImpl;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.cache.LocalDataSet;
-import com.gemstone.gemfire.internal.cache.PartitionedRegion;
-import com.gemstone.gemfire.internal.cache.PartitionedRegion.RecoveryLock;
-import com.gemstone.gemfire.internal.cache.PartitionedRegionHelper;
-import com.gemstone.gemfire.internal.cache.control.RebalanceResultsImpl;
-import com.gemstone.gemfire.internal.cache.execute.InternalRegionFunctionContext;
-import com.gemstone.gemfire.internal.cache.partitioned.PartitionedRegionRebalanceOp;
-import com.gemstone.gemfire.internal.cache.partitioned.rebalance.ExplicitMoveDirector;
-import com.gemstone.gemfire.internal.cache.partitioned.rebalance.PercentageMoveDirector;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.DataPolicy;
+import org.apache.geode.cache.PartitionAttributes;
+import org.apache.geode.cache.PartitionAttributesFactory;
+import org.apache.geode.cache.PartitionResolver;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.control.RebalanceResults;
+import org.apache.geode.cache.control.ResourceManager;
+import org.apache.geode.cache.execute.Function;
+import org.apache.geode.cache.execute.FunctionService;
+import org.apache.geode.cache.execute.RegionFunctionContext;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.internal.cache.ColocationHelper;
+import org.apache.geode.internal.cache.FixedPartitionAttributesImpl;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.cache.LocalDataSet;
+import org.apache.geode.internal.cache.PartitionedRegion;
+import org.apache.geode.internal.cache.PartitionedRegion.RecoveryLock;
+import org.apache.geode.internal.cache.PartitionedRegionHelper;
+import org.apache.geode.internal.cache.control.RebalanceResultsImpl;
+import org.apache.geode.internal.cache.execute.InternalRegionFunctionContext;
+import org.apache.geode.internal.cache.partitioned.PartitionedRegionRebalanceOp;
+import org.apache.geode.internal.cache.partitioned.rebalance.ExplicitMoveDirector;
+import org.apache.geode.internal.cache.partitioned.rebalance.PercentageMoveDirector;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * Utility methods for handling partitioned Regions, for example

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionInfo.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/persistence/ConflictingPersistentDataException.java b/geode-core/src/main/java/org/apache/geode/cache/persistence/ConflictingPersistentDataException.java
index f65ffc8..26f16ec 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/persistence/ConflictingPersistentDataException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/persistence/ConflictingPersistentDataException.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.persistence;
+package org.apache.geode.cache.persistence;
 
-import com.gemstone.gemfire.GemFireException;
-import com.gemstone.gemfire.admin.AdminDistributedSystem;
+import org.apache.geode.GemFireException;
+import org.apache.geode.admin.AdminDistributedSystem;
 
 /**
  * Thrown when a member with persistence is recovering, and it discovers that

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/persistence/PartitionOfflineException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/persistence/PartitionOfflineException.java b/geode-core/src/main/java/org/apache/geode/cache/persistence/PartitionOfflineException.java
index 20d2a50..fe30bce 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/persistence/PartitionOfflineException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/persistence/PartitionOfflineException.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.persistence;
+package org.apache.geode.cache.persistence;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * Thrown when a paritioned region is configured for disk persistence,

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentID.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentID.java b/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentID.java
index d0169dc..256e208 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentID.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentID.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.persistence;
+package org.apache.geode.cache.persistence;
 
 import java.net.InetAddress;
 import java.util.UUID;
 
-import com.gemstone.gemfire.DataSerializable;
-import com.gemstone.gemfire.admin.AdminDistributedSystem;
-import com.gemstone.gemfire.cache.DataPolicy;
+import org.apache.geode.DataSerializable;
+import org.apache.geode.admin.AdminDistributedSystem;
+import org.apache.geode.cache.DataPolicy;
 
 /**
  * A pattern describing a single member's a set of persistent files for a region.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentReplicatesOfflineException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentReplicatesOfflineException.java b/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentReplicatesOfflineException.java
index f53ecb1..a51c979 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentReplicatesOfflineException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/persistence/PersistentReplicatesOfflineException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.persistence;
+package org.apache.geode.cache.persistence;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * Thrown when a replicated region is configured for persistence

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokeFailedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokeFailedException.java b/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokeFailedException.java
index 5d3bcde..88fbf81 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokeFailedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokeFailedException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.persistence;
+package org.apache.geode.cache.persistence;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * Thrown when a member tries to revoke a persistent ID, but the member

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokedPersistentDataException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokedPersistentDataException.java b/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokedPersistentDataException.java
index e9b0d11..35a8ea5 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokedPersistentDataException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/persistence/RevokedPersistentDataException.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.persistence;
+package org.apache.geode.cache.persistence;
 
-import com.gemstone.gemfire.GemFireException;
-import com.gemstone.gemfire.admin.AdminDistributedSystem;
+import org.apache.geode.GemFireException;
+import org.apache.geode.admin.AdminDistributedSystem;
 
 /**
  * Thrown when a member with persistence is recovering, and it discovers that

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/Aggregator.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/Aggregator.java b/geode-core/src/main/java/org/apache/geode/cache/query/Aggregator.java
index 6991e53..d4dba92 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/Aggregator.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/Aggregator.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Behavior of a user-defined aggregator. Aggregates values and returns a

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/AmbiguousNameException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/AmbiguousNameException.java b/geode-core/src/main/java/org/apache/geode/cache/query/AmbiguousNameException.java
index 3e54278..5715e9e 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/AmbiguousNameException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/AmbiguousNameException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if an attribute or method name in a query can be resolved to

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributes.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributes.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributes.java
index 7a70d61..fff4a33 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributes.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributes.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /** 
  * This interface holds all attribute values for a CQ and provides methods for 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesFactory.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesFactory.java
index 1e0c88a..d47250e 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesFactory.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesFactory.java
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-import com.gemstone.gemfire.cache.query.internal.cq.CqAttributesImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.query.internal.cq.CqAttributesImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * The factory class for the CqAttributes instance. This provides the CqListener 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesMutator.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesMutator.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesMutator.java
index 05f64e4..40969f6 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesMutator.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqAttributesMutator.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * This interface is used to modify the listeners that are associated with a CQ. 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqClosedException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqClosedException.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqClosedException.java
index 3adb761..2e5f25d 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqClosedException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqClosedException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.CacheRuntimeException;
+import org.apache.geode.cache.CacheRuntimeException;
 
 /**
  * Thrown if the CqQuery on which the operation performed is closed.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqEvent.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqEvent.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqEvent.java
index dccb383..57e83d4 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqEvent.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqEvent.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.Operation;
+import org.apache.geode.cache.Operation;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqException.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqException.java
index 0f0f2fd..c02c71a 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown during continuous query creation, execution time.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqExistsException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqExistsException.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqExistsException.java
index 66ffd08..31774cb 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqExistsException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqExistsException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if a CQ by this name already exists on this client 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqListener.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqListener.java
index b68d976..7b0a8d3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqListener.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.CacheCallback;
+import org.apache.geode.cache.CacheCallback;
 
 /**
  * Application plug-in interface for handling continuous query events after 
@@ -43,7 +43,7 @@ public interface CqListener extends CacheCallback {
    * operation and CQ registration to avoid duplicate event being 
    * delivered.   
    * 
-   * @see com.gemstone.gemfire.cache.query.CqQuery#executeWithInitialResults
+   * @see org.apache.geode.cache.query.CqQuery#executeWithInitialResults
    */
   public void onEvent(CqEvent aCqEvent);
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqQuery.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqQuery.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqQuery.java
index 691a7d0..5282706 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqQuery.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqQuery.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqResults.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqResults.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqResults.java
index f11e4e5..80a5f96 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqResults.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqResults.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Represents the results of a CQ query that is executed using 
- * {@linkplain com.gemstone.gemfire.cache.query.CqQuery#executeWithInitialResults()}
+ * {@linkplain org.apache.geode.cache.query.CqQuery#executeWithInitialResults()}
  * The result will contain the instances of {@link Struct} having key and value 
  * of the region entry that satisfy the CQ query condition.
  * <pre>
@@ -41,8 +41,8 @@ package com.gemstone.gemfire.cache.query;
  *
  * </pre>
  * 
- * @see com.gemstone.gemfire.cache.query.Query#execute()
- * @see com.gemstone.gemfire.cache.query.CqQuery#executeWithInitialResults()
+ * @see org.apache.geode.cache.query.Query#execute()
+ * @see org.apache.geode.cache.query.CqQuery#executeWithInitialResults()
  * 
  * @since GemFire 6.5
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqServiceStatistics.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqServiceStatistics.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqServiceStatistics.java
index b1477f2..533eb9c 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqServiceStatistics.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqServiceStatistics.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * This class provides methods to get aggregate statistical information 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqState.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqState.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqState.java
index 0ade80d..fa900de 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqState.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqState.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * This interface gives information on the state of a CqQuery. 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqStatistics.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqStatistics.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqStatistics.java
index 1189179..a0128e5 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqStatistics.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqStatistics.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * This class provides methods to get statistical information about a registered Continuous Query (CQ)

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/CqStatusListener.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/CqStatusListener.java b/geode-core/src/main/java/org/apache/geode/cache/query/CqStatusListener.java
index 0f1e372..35a6a90 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/CqStatusListener.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/CqStatusListener.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/FunctionDomainException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/FunctionDomainException.java b/geode-core/src/main/java/org/apache/geode/cache/query/FunctionDomainException.java
index d6fe92d..3a1379b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/FunctionDomainException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/FunctionDomainException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if the domain of a function is not legal.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/Index.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/Index.java b/geode-core/src/main/java/org/apache/geode/cache/query/Index.java
index 56593f4..f4f4c21 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/Index.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/Index.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 //import java.util.*;
-import com.gemstone.gemfire.cache.*;
+import org.apache.geode.cache.*;
 
 /**
  * An index that is built over the data stored in a GemFire {@link

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexCreationException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexCreationException.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexCreationException.java
index 75613e8..88bdee6 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexCreationException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexCreationException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 /**
  * This class is used to represent any partitioned index creation exceptions.
  * 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexExistsException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexExistsException.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexExistsException.java
index 5a0c317..2fe9d83 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexExistsException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexExistsException.java
@@ -20,7 +20,7 @@
  * Created on February 15, 2005, 10:20 AM
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown while creating the new index if there exists an Index with

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexInvalidException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexInvalidException.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexInvalidException.java
index 0426cd1..1f246a9 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexInvalidException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexInvalidException.java
@@ -20,9 +20,9 @@
  * Created on March 16, 2005, 7:40 PM
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * Thrown if the index definition is not valid.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexMaintenanceException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexMaintenanceException.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexMaintenanceException.java
index 3dda5b4..44f71d0 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexMaintenanceException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexMaintenanceException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.CacheRuntimeException;
+import org.apache.geode.cache.CacheRuntimeException;
 /**
  * Thrown if an error occurs while updating query indexes during
  * region modification.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexNameConflictException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexNameConflictException.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexNameConflictException.java
index a4b13ed..5e6264b 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexNameConflictException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexNameConflictException.java
@@ -20,7 +20,7 @@
  * Created on February 15, 2005, 10:20 AM
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown while creating the new index if there exists an Index with

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexStatistics.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexStatistics.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexStatistics.java
index 1148b61..5cfd1c5 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexStatistics.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexStatistics.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 //import java.util.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/IndexType.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/IndexType.java b/geode-core/src/main/java/org/apache/geode/cache/query/IndexType.java
index 362de5a..be62f13 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/IndexType.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/IndexType.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * @deprecated As of 6.6.1. Check {@link QueryService} for changes.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/MultiIndexCreationException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/MultiIndexCreationException.java b/geode-core/src/main/java/org/apache/geode/cache/query/MultiIndexCreationException.java
index 42563fc..92a1d05 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/MultiIndexCreationException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/MultiIndexCreationException.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.query.internal.DefaultQueryService;
+import org.apache.geode.cache.query.internal.DefaultQueryService;
 
 /**
  * Consists a map of index names and Exceptions thrown during index creation

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/NameNotFoundException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/NameNotFoundException.java b/geode-core/src/main/java/org/apache/geode/cache/query/NameNotFoundException.java
index aad2ec3..a65d1c6 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/NameNotFoundException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/NameNotFoundException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/NameResolutionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/NameResolutionException.java b/geode-core/src/main/java/org/apache/geode/cache/query/NameResolutionException.java
index ffb5c16..c02a2a3 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/NameResolutionException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/NameResolutionException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if an attribute or method name in a query cannot be resolved.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/ParameterCountInvalidException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/ParameterCountInvalidException.java b/geode-core/src/main/java/org/apache/geode/cache/query/ParameterCountInvalidException.java
index c91dceb..91600c2 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/ParameterCountInvalidException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/ParameterCountInvalidException.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown when the number of bound paramters for a query does not match the

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/Query.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/Query.java b/geode-core/src/main/java/org/apache/geode/cache/query/Query.java
index fdd71b0..e27687d 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/Query.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/Query.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.Region;
-import com.gemstone.gemfire.cache.execute.Function;
-import com.gemstone.gemfire.cache.execute.FunctionContext;
-import com.gemstone.gemfire.cache.execute.FunctionService;
-import com.gemstone.gemfire.cache.execute.RegionFunctionContext;
+import org.apache.geode.cache.Region;
+import org.apache.geode.cache.execute.Function;
+import org.apache.geode.cache.execute.FunctionContext;
+import org.apache.geode.cache.execute.FunctionService;
+import org.apache.geode.cache.execute.RegionFunctionContext;
 
 /**
  * Interface for query objects. Supports execution of queries with optional

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryException.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryException.java
index 3ddd320..db7faa8 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.GemFireCheckedException;
+import org.apache.geode.GemFireCheckedException;
 
 /**
  * Thrown during by the query engine during parsing or execution.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionLowMemoryException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionLowMemoryException.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionLowMemoryException.java
index c0ba18d..0c57ea6 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionLowMemoryException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionLowMemoryException.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.CacheRuntimeException;
-import com.gemstone.gemfire.cache.control.ResourceManager;
+import org.apache.geode.cache.CacheRuntimeException;
+import org.apache.geode.cache.control.ResourceManager;
 /**
  * Thrown when the query is executing and the critical heap percentage is met.
  * @see ResourceManager#setCriticalHeapPercentage(float)

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionTimeoutException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionTimeoutException.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionTimeoutException.java
index a8689bb..01c3645 100755
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionTimeoutException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryExecutionTimeoutException.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.cache.CacheRuntimeException;
+import org.apache.geode.cache.CacheRuntimeException;
 /**
  * Thrown when the query execution takes more than the specified max time.
  * The Max query execution time is set using the system  variable 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvalidException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvalidException.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvalidException.java
index 0f6116e..ba3b0e4 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvalidException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvalidException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * Thrown if the query language syntax is not valid.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvocationTargetException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvocationTargetException.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvocationTargetException.java
index 47aea3c..1bff735 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvocationTargetException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryInvocationTargetException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if an exception is thrown when a method is invoked during query execution.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryService.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryService.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryService.java
index 28646a4..badca42 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryService.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryService.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 import java.util.*;
-import com.gemstone.gemfire.cache.*;
-import com.gemstone.gemfire.cache.query.internal.Undefined;
+import org.apache.geode.cache.*;
+import org.apache.geode.cache.query.internal.Undefined;
 
 /**
  * Interface for the query service, which is used for instantiating queries, 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/QueryStatistics.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/QueryStatistics.java b/geode-core/src/main/java/org/apache/geode/cache/query/QueryStatistics.java
index c305573..b0f1275 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/QueryStatistics.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/QueryStatistics.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Provides statistical information about a query performed on a

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/RegionNotFoundException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/RegionNotFoundException.java b/geode-core/src/main/java/org/apache/geode/cache/query/RegionNotFoundException.java
index a52f54c..22d2376 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/RegionNotFoundException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/RegionNotFoundException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if a region referenced by name in a query cannot be found.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/SelectResults.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/Struct.java b/geode-core/src/main/java/org/apache/geode/cache/query/Struct.java
index 8ff6a15..493ab41 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/Struct.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/Struct.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 //import java.util.*;
-import com.gemstone.gemfire.cache.query.types.StructType;
+import org.apache.geode.cache.query.types.StructType;
 
 /**
  * An immutable and thread-safe data type used by the result of some

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/TypeMismatchException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/TypeMismatchException.java b/geode-core/src/main/java/org/apache/geode/cache/query/TypeMismatchException.java
index 6c6e0aa..90a3646 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/TypeMismatchException.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/TypeMismatchException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 /**
  * Thrown if type consistency is violated while a query is being executed.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/internal/AbstractCompiledValue.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/internal/AbstractCompiledValue.java b/geode-core/src/main/java/org/apache/geode/cache/query/internal/AbstractCompiledValue.java
index b6136dc..2388545 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/internal/AbstractCompiledValue.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/internal/AbstractCompiledValue.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.cache.query.internal;
+package org.apache.geode.cache.query.internal;
 
 import java.util.*;
-import com.gemstone.gemfire.cache.query.*;
-import com.gemstone.gemfire.cache.query.types.*;
-import com.gemstone.gemfire.cache.query.internal.parse.OQLLexerTokenTypes;
-import com.gemstone.gemfire.cache.query.internal.types.StructTypeImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.cache.query.*;
+import org.apache.geode.cache.query.types.*;
+import org.apache.geode.cache.query.internal.parse.OQLLexerTokenTypes;
+import org.apache.geode.cache.query.internal.types.StructTypeImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
-//import com.gemstone.gemfire.cache.query.internal.types.TypeUtils;
+//import org.apache.geode.cache.query.internal.types.TypeUtils;
 /**
  * Class Description
  *
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRebalanceInfo.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRebalanceInfo.java
index 7b5f914..4e7d996 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRebalanceInfo.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRebalanceInfo.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
 import java.util.Set;
 
@@ -27,7 +27,7 @@ import java.util.Set;
 public interface PartitionRebalanceInfo {
   
   /**
    * Returns the {@link com.gemstone.gemfire.cache.Region#getFullPath() 
    * full path} of the partitioned region that these details describe.
    * 
    * @return the full name of partioned region that these details describe.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionHelper.java
----------------------------------------------------------------------
@@ -27,7 +27,7 @@ import java.util.Set;
   
   /**
-   * Returns the {@link com.gemstone.gemfire.cache.Region#getFullPath() 
+   * Returns the {@link org.apache.geode.cache.Region#getFullPath() 
    * full path} of the partitioned region that these details describe.
    * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionInfo.java b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionInfo.java
index 223e5cd..406fba1 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionInfo.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/partition/PartitionRegionInfo.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.partition;
+package org.apache.geode.cache.partition;
 
 import java.util.Set;
 
-import com.gemstone.gemfire.cache.control.ResourceManager;
+import org.apache.geode.cache.control.ResourceManager;
 
 /**
  * Information describing the data storage and distribution of a 
@@ -34,7 +34,7 @@ import com.gemstone.gemfire.cache.control.ResourceManager;
 public interface PartitionRegionInfo {
 
   /**
    * Returns the {@link com.gemstone.gemfire.cache.Region#getFullPath() 
    * full path} of the partitioned region that this object describes.
    * 
    * @return the full path of the partitioned region that this info describes
@@ -52,7 +52,7 @@ public interface PartitionRegionInfo {
   
   /**
    * Returns the {@link 
-   * com.gemstone.gemfire.cache.PartitionAttributes#getTotalNumBuckets()
+   * org.apache.geode.cache.PartitionAttributes#getTotalNumBuckets()
    * configured number of buckets} for the partitioned region.
    * 
    * @return the configured number of buckets
@@ -81,7 +81,7 @@ public interface PartitionRegionInfo {
   
   /**
    * Returns the number of {@link 
-   * com.gemstone.gemfire.cache.PartitionAttributes#getRedundantCopies()
+   * org.apache.geode.cache.PartitionAttributes#getRedundantCopies()
    * redundant copies} the partitioned region was configured for.
    * 
    * @return the number of redundant copies the partitioned region was 
@@ -101,9 +101,9 @@ public interface PartitionRegionInfo {
   public int getActualRedundantCopies();
   
   /**
    * Returns the {@link com.gemstone.gemfire.cache.Region#getFullPath() 
    * full path} of the partitioned region that this region has been configured 
    * to be {@link com.gemstone.gemfire.cache.PartitionAttributes#getColocatedWith() 
    * colocated with} or null if it is not colocated.
    * 
    * @return the full path of the partitioned region that the region is 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/persistence/ConflictingPersistentDataException.java
----------------------------------------------------------------------
@@ -34,7 +34,7 @@ import com.gemstone.gemfire.cache.control.ResourceManager;
 
   /**
-   * Returns the {@link com.gemstone.gemfire.cache.Region#getFullPath() 
+   * Returns the {@link org.apache.geode.cache.Region#getFullPath() 
    * full path} of the partitioned region that this object describes.
    * 
@@ -101,9 +101,9 @@ public interface PartitionRegionInfo {
   
   /**
-   * Returns the {@link com.gemstone.gemfire.cache.Region#getFullPath() 
+   * Returns the {@link org.apache.geode.cache.Region#getFullPath() 
    * full path} of the partitioned region that this region has been configured 
@@ -101,9 +101,9 @@ public interface PartitionRegionInfo {
    * full path} of the partitioned region that this region has been configured 
-   * to be {@link com.gemstone.gemfire.cache.PartitionAttributes#getColocatedWith() 
+   * to be {@link org.apache.geode.cache.PartitionAttributes#getColocatedWith() 
    * colocated with} or null if it is not colocated.
    * 
diff --git a/geode-core/src/main/java/org/apache/geode/cache/query/SelectResults.java b/geode-core/src/main/java/org/apache/geode/cache/query/SelectResults.java
index b7359e6..1b8d9a4 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/query/SelectResults.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/query/SelectResults.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.cache.query;
+package org.apache.geode.cache.query;
 
 import java.util.*;
-import com.gemstone.gemfire.cache.query.types.*;
+import org.apache.geode.cache.query.types.*;
 
 /**
  * Contains the results of a {@linkplain com.gemstone.gemfire.cache.query.Query#execute() executing} a
  * <code>SELECT</code> expression within a query. A <code>SELECT</code>
  * expression results in <code>SelectResults</code> that contain instances of
  * {@link Struct} if: (a) there is more than one projection in the projection
@@ -60,7 +60,7 @@ import com.gemstone.gemfire.cache.query.types.*;
  *
  * </pre>
  *
- * @see com.gemstone.gemfire.cache.query.Query#execute()
+ * @see org.apache.geode.cache.query.Query#execute()
  *
  * @since GemFire 4.0
  */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/939fcf2f/geode-core/src/main/java/org/apache/geode/cache/query/Struct.java
----------------------------------------------------------------------
@@ -15,13 +15,13 @@
 
 /**
- * Contains the results of a {@linkplain com.gemstone.gemfire.cache.query.Query#execute() executing} a
+ * Contains the results of a {@linkplain org.apache.geode.cache.query.Query#execute() executing} a
  * <code>SELECT</code> expression within a query. A <code>SELECT</code>
  * expression results in <code>SelectResults</code> that contain instances of